<no title> — durian v0.0.1 documentation

### Navigation

- index
- modules |
- previous |
- durian v0.0.1 documentation »

#### Previous topic

Matching Strategies - durian.match.strategy

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- previous |
- durian v0.0.1 documentation »

© Copyright 2009, Opera Softare (WebTeam). Created using Sphinx 0.6.3.